@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-"""颜色表示"""
+"""颜色数据类"""
+
+from Annotations2Sub.utils import _
 
 
 class Color:
-    """以 0-255 的整数表示颜色值, 不提供序列化方法"""
-
     def __init__(
         self,
         red: int = 0,
@@ -14,29 +14,26 @@ class Color:
         blue: int = 0,
     ):
         if red > 255:
-            raise ValueError("red must be 0-255")
+            raise ValueError(_('"red" 必须在 0-255 之间'))
         if green > 255:
-            raise ValueError("green must be 0-255")
+            raise ValueError(_('"green" 必须在 0-255 之间'))
         if blue > 255:
-            raise ValueError("blue must be 0-255")
+            raise ValueError(_('"blue" 必须在 0-255 之间'))
         self.red = red
         self.green = green
         self.blue = blue
 
 
 class Alpha:
-    """以 0-255 的整数表示透明度, 255 是不透明, 不提供序列化方法"""
-
-    def __init__(
-        self,
-        alpha: int = 0,
-    ):
+    def __init__(self, alpha: int = 0):
         if alpha > 255:
-            raise ValueError("alpha must be 0-255")
+            raise ValueError(_('"alpha" 必须在 0-255 之间'))
         self.alpha = alpha
 
 
 class Rgba:
     def __init__(self, color: Color = Color(), alpha: Alpha = Alpha()):
-        self.color = color
-        self.alpha = alpha
+        self.red = color.red
+        self.green = color.green
+        self.blue = color.blue
+        self.alpha = alpha.alpha
