@@ -1,18 +1,18 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__version__ = "2.5.0"
+"""Annotations2Sub, 一个能把 Youtube 注释转换成 Advanced SubStation Alpha 字幕文件的脚本"""
+
+__version__ = "2.15.1"
 
 """
-Annotations2Sub, 一个能把 Youtube 注释转换成 Advanced SubStation Alpha 字幕文件的脚本
-
                                             xml.
                                             etree.
-┌────────────────┐            ┌────────┐    ElementTree.  ┌─────────┐
-│                │    read()  │        │    fromstring()  │         │     Parse()
-│ Annotation.xml │ ─────────► │ String │ ───────────────► │ Element │ ────────────┐
-│                │            │        │                  │         │             │
-└────────────────┘            └────────┘                  └─────────┘             │
+┌─────────────────┐            ┌────────┐    ElementTree.  ┌─────────┐
+│                 │    read()  │        │    fromstring()  │         │     Parse()
+│ Annotations.xml │ ─────────► │ String │ ───────────────► │ Element │ ────────────┐
+│                 │            │        │                  │         │             │
+└─────────────────┘            └────────┘                  └─────────┘             │
                                                                                   ▼
                                                                          ┌──────────────────┐
                                                                          │                  │
@@ -20,11 +20,11 @@ Annotations2Sub, 一个能把 Youtube 注释转换成 Advanced SubStation Alpha
                                                                          │                  │
                                                                          └──────────────────┘
 
-┌────────────────┐            ┌────────┐  Sub.      ┌─────────────┐               │
-│                │  finally   │        │  Dump()    │             │  Convert()    │
-│ Annotation.ass │ ◄───────── │ String │ ◄───────── │ List[Event] │ ◄─────────────┘
-│                │            │        │            │             │
-└────────────────┘            └────────┘            └─────────────┘
+┌─────────────────┐            ┌────────┐  Sub.      ┌─────────────┐               │
+│                 │  finally   │        │  Dump()    │             │  Convert()    │
+│ Annotations.ass │ ◄───────── │ String │ ◄───────── │ List[Event] │ ◄─────────────┘
+│                 │            │        │            │             │
+└─────────────────┘            └────────┘            └─────────────┘
 
 https://www.youtube.com/channel/UCe4QujtMby3h6dge1eYaPig
 在 2019 年的某一天, 我在 Youtube 听歌, 发现字幕没了.
@@ -44,7 +44,7 @@ https://www.youtube.com/channel/UCe4QujtMby3h6dge1eYaPig
 此项目早期(8e2d8eb 第一个勉强可用的版本)参照 https://github.com/nirbheek/youtube-ass 实现了一个简单的转换器, 
 参照 https://github.com/weizhenye/ASS/wiki/ASS-字幕格式规范 实现了一个简单的 Advanced SubStation Alpha 生成器
 使用 "样式覆写代码" 实现了定位和颜色
-之后(a64995 庆祝一下), 使用 "绘图模式" 实现了 "popup" 样式
+之后(a649956 庆祝一下), 使用 "绘图模式" 实现了 "popup" 样式
 在 https://invidious.io/ 和 FFmpeg 的帮助下, 实现了简单的视频预览
 之后, 脚本逐步完善, 完成了 https://www.bilibili.com/video/BV1Ff4y1t7Dj
 但是还是有些遗憾
@@ -61,7 +61,7 @@ R4CqsDTnT60	志方あきこ - Ec Tisia ～Tarifa～ 中文字幕(Chinese Transla
 ---
 
 作为我的第一个代码, 我一直想让其趋于完美.
-首先想的是参考 https://github.com/isaackd/annotationlib (致谢), 将 Annotation 抽成一个简单的结构, 
+首先想的是参考 https://github.com/isaackd/annotationlib (致谢), 将 Annotations 抽成一个简单的结构, 
 与脚本生成器(转换器)解耦, 结果并没有让事情变简单. (2020)
 之后还尝试过实现 speech 样式, 把事情弄得一团糟
 还尝试过扔掉 invidious , 发现我简直像个shaberhu (2021)
@@ -69,10 +69,27 @@ R4CqsDTnT60	志方あきこ - Ec Tisia ～Tarifa～ 中文字幕(Chinese Transla
 ...
 拜奥密克戎所赐自从 2022 年我已经有半年呆在家里了, 我有了时间可以一直折腾代码, 我决定再次挑战这个目标.
 首先, 我依照写 Go 的经验将脚本拆成了模块, 编写单元测试, 进行类型检查, 一键格式化
-然后, 尝试将 Annotation 抽成一个简单的结构
+然后, 尝试将 Annotations 抽成一个简单的结构
 最后, 对其进行详尽的注释, 到目前为止看起来不错.
 ...
 差不多完事儿了, 剩下的时间就是维护代码了.
 
+---
+
+没想到还有 https://github.com/po5/assnotations
+...
+
+---
+- 注释(Annotations): YouTube 的功能
+- SSA(Sub Station Alpha): 字幕格式
+- ASS(Advanced SubStation Alpha): 字幕格式
+- invidious(https://invidious.io/): 开源 YouTube 前端
+
 """
 version = __version__
+
+from Annotations2Sub.Annotations import Annotation, Parse
+from Annotations2Sub.Convert import Convert
+from Annotations2Sub.Sub import Sub
+
+__all__ = ["Parse", "Annotation", "Convert", "Sub", "version"]
