@@ -7,15 +7,15 @@ import pytest
 from Annotations2Sub.Color import Alpha, Color
 
 
-def test_Alpha():
-    with pytest.raises(ValueError):
-        Alpha(256)
-
-
-def test_Color():
+def test_Color_ValueError():
     with pytest.raises(ValueError):
         Color(256, 0, 0)
     with pytest.raises(ValueError):
         Color(0, 256, 0)
     with pytest.raises(ValueError):
         Color(0, 0, 256)
+
+
+def test_Alpha_ValueError():
+    with pytest.raises(ValueError):
+        Alpha(256)
